@@ -1,14 +1,17 @@
+from __future__ import annotations
+
 import asyncio
 import json
 import mimetypes
 import os
 from asyncio import AbstractEventLoop
+from collections.abc import AsyncIterable
 from concurrent.futures import ThreadPoolExecutor
 from email.utils import formatdate
 from enum import Enum
 from http import HTTPStatus
 from http.cookies import SimpleCookie
-from typing import Any, AsyncIterable, Optional
+from typing import Any, Optional
 
 from asgikit.files import AsyncFile
 
@@ -38,8 +41,8 @@ class HttpResponse:
 
     def __init__(
         self,
-        status: HTTPStatus = HTTPStatus.OK,
         content: Any = None,
+        status: HTTPStatus = HTTPStatus.OK,
         content_type: str = None,
         encoding: str = None,
         headers: MutableHeaders | dict[str, str] | dict[str, list[str]] = None,
@@ -60,14 +63,16 @@ class HttpResponse:
         elif isinstance(headers, (dict, list)):
             self.headers = MutableHeaders(headers)
         else:
-            raise ValueError("'headers' must be instance of 'dict' or 'MutableHeaders'")
+            raise ValueError(
+                "'headers' must be instance of 'dict[str, str | list[str]' or 'MutableHeaders'"
+            )
 
         self.cookies = SimpleCookie()
 
         self._is_initialized = False
         self._body = None
 
-    def header(self, name: str, value: str) -> "HttpResponse":
+    def header(self, name: str, value: str) -> HttpResponse:
         self.headers.set(name, value)
         return self
 
@@ -82,7 +87,7 @@ class HttpResponse:
         secure: bool = False,
         httponly: bool = True,
         samesite: SameSitePolicy = SameSitePolicy.LAX,
-    ) -> "HttpResponse":
+    ) -> HttpResponse:
         self.cookies[name] = value
         if expires is not None:
             self.cookies[name]["expires"] = expires
@@ -196,7 +201,7 @@ class RedirectPostGetResponse(HttpResponse):
 
 class StreamingResponse(HttpResponse):
     def __init__(
-        self, stream: AsyncIterable[bytes], content_type: str = None, headers=None
+        self, stream: AsyncIterable[bytes | str], content_type: str = None, headers=None
     ):
         super().__init__(content=None, content_type=content_type, headers=headers)
         self.stream = stream
@@ -209,7 +214,7 @@ class StreamingResponse(HttpResponse):
 
     async def _send_response(self, send):
         async for chunk in self.stream:
-            if not isinstance(chunk, bytes):
+            if isinstance(chunk, str):
                 chunk = chunk.encode(self.encoding)
 
             await send(
